@@ -140,8 +140,9 @@ class LuaScripts(object):
                 redis.call('HSET', profile_key, '_created', timestamp_now)
             end
 
-            local function update_profile_prop (p_key, v_key, v, field_type)
+            local function update_profile_prop (p_key, v_key, obj, field_type)
                 local current_value = redis.call('HGET', p_key, v_key)
+                local v = obj["value"]
                 if field_type == 'counter' then
                     redis.call('HINCRBY', p_key, v_key, v)
                 elseif field_type == 'sfloat' then
@@ -177,7 +178,28 @@ class LuaScripts(object):
                 elseif field_type == 'fcfloat' then
                     if current_value == false then
                         redis.call('HSET', p_key, v_key, v)
-                    end                    
+                    end    
+                elseif field_type == 'tw30count' then
+                    local threshold_ts = tonumber(obj["thr"])
+                    local new_counter_data = {{}}
+                    for day_key, val in pairs(cjson.decode(v)) do
+                        if tonumber(day_key) >= threshold_ts then
+                            new_counter_data[tostring(day_key)] = val
+                        end
+                    end
+                    if current_value == false then
+                        local counter_data_str = cjson.encode(new_counter_data)
+                        redis.call('HSET', p_key, v_key, counter_data_str)
+                    else
+                        local counter_data = cjson.decode(current_value)
+                        for k, val in pairs(counter_data) do
+                            if tonumber(k) >= threshold_ts then
+                                new_counter_data[k] = tonumber((new_counter_data[k] or 0)) + val
+                            end
+                        end
+                        local counter_data_str = cjson.encode(new_counter_data)
+                        redis.call('HSET', p_key, v_key, counter_data_str)
+                    end      
                 end 
             end
 
@@ -194,7 +216,7 @@ class LuaScripts(object):
                         -- the key does not exist yet
                         if (obj.expire_at == nil or obj.expire_at > timestamp_now) and obj["value"] ~= nil then
                             -- only create if the new expire time is in the future
-                            update_profile_prop(profile_key, value_key, obj["value"], field_type)
+                            update_profile_prop(profile_key, value_key, obj, field_type)
                             redis.call('HMSET', profile_key, updated_key, timestamp_now, created_key, timestamp_now)
                             if obj.expire_at ~= nil then
                                 redis.call('HSET', profile_key, expire_key, obj.expire_at)  
@@ -215,7 +237,7 @@ class LuaScripts(object):
                         if obj.expire_at == nil or obj.expire_at > timestamp_now then
                             -- create/update the key if its not expired
                             if obj["value"] ~= nil or not deleted_key then
-                                update_profile_prop(profile_key, value_key, obj["value"], field_type)
+                                update_profile_prop(profile_key, value_key, obj, field_type)
                                 redis.call('HSET', profile_key, updated_key, timestamp_now)  
                                 if deleted_key then
                                     redis.call('HSET', profile_key, created_key, timestamp_now)
@@ -271,6 +293,10 @@ class LuaScripts(object):
             if profile_update.or_booleans ~= nil then
                 update_profile(profile_update.or_booleans, 'orbool')
             end
+            
+            if profile_update.time_window30_counters ~= nil then
+                update_profile(profile_update.time_window30_counters, 'tw30count')
+            end
 
             -- add profile_key to sorted set of all profile keys
             redis.call('ZADD', KEYS[2], timestamp_now, profile_key)            
