@@ -487,7 +487,7 @@ class Profile(object):
     @staticmethod
     def to_short_data(props):
 
-        return {k: v.value for k, v in props.items()}
+        return {k: v.output_value for k, v in props.items()}
 
     @property
     def data(self):
